@@ -204,7 +204,7 @@ pub fn list_up_contents(path: &Path, width: u16) -> Result<String, FxError> {
 
 /// Format texts to print. Used when printing help or text preview.
 pub fn format_txt(txt: &str, width: u16, is_help: bool) -> Vec<String> {
-    let mut v = split_lines_includng_wide_char(txt, width.into());
+    let mut v = split_lines_including_wide_char(txt, width.into());
     if is_help {
         v.push("Press Enter to go back.".to_owned());
     }
@@ -252,30 +252,6 @@ pub fn init_log(data_local_path: &Path) -> Result<(), FxError> {
     Ok(())
 }
 
-/// Check the latest version of felix.
-pub fn check_version() -> Result<(), FxError> {
-    let output = std::process::Command::new("cargo")
-        .args(["search", "felix", "--limit", "1"])
-        .output()?
-        .stdout;
-    if !output.is_empty() {
-        if let Ok(ver) = std::str::from_utf8(&output) {
-            let latest: String = ver.chars().skip(9).take_while(|x| *x != '\"').collect();
-            let current = env!("CARGO_PKG_VERSION");
-            if latest != current {
-                println!("felix v{}: Latest version is {}.", current, latest);
-            } else {
-                println!("felix v{}: Up to date.", current);
-            }
-        } else {
-            println!("Cannot read the version.");
-        }
-    } else {
-        println!("Cannot fetch the latest version: Check your internet connection.");
-    }
-    Ok(())
-}
-
 /// linux-specific: Convert u32 to permission-ish string.
 pub fn convert_to_permissions(permissions: u32) -> String {
     let permissions = format!("{permissions:o}");
@@ -299,7 +275,7 @@ pub fn shorten_str_including_wide_char(s: &str, i: usize) -> String {
     result
 }
 
-fn split_lines_includng_wide_char(s: &str, width: usize) -> Vec<String> {
+fn split_lines_including_wide_char(s: &str, width: usize) -> Vec<String> {
     let mut result = vec![];
     let mut new_line = "".to_owned();
     for c in s.chars() {
